#!/bin/sh
# This program is free software: you can redistribute it and/or modify it
# under the terms of the the GNU General Public License version 3, as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
# PURPOSE.  See the applicable version of the GNU General Public
# License for more details.
#.
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Copyright (C) 2014 Canonical, Ltd.
#
# Author: Francis Ginther <francis.ginther@canonical.com>
set -x
export LC_ALL=C

usage() {
cat <<EOF
usage: $0 [OPTIONS]

Installs a custom built click app and autopilot tests

OPTIONS:
  -h	Show this message
  -s    Specify the serial of the device to install (see adb $ADBOPTS devices)

  --source-dir	sources used to backreference the package
  --click       the click package to install
EOF
}

ADBOPTS=""
SOURCE_DIR=""
CLICK=""

TEST_DIR='tests/autopilot'
DEVICE_USER='phablet'

ARGS=$(getopt -o s:h -l "source-dir:,click:,help" -n "$0" -- "$@")

if [ $? -ne 0 ] ; then
    exit 1
fi
eval set -- "$ARGS"

while true; do
    case "$1" in
        -h|--help)
            usage
            exit 0
            ;;
        -s)
            shift;
            ADBOPTS="-s $1"
            shift;
            ;;
        --click)
            shift
            CLICK="$1"
            shift
            ;;
        --source-dir)
            shift
            SOURCE_DIR="$(readlink -f $1)"
            shift
            ;;
        --)
            shift;
            break;
            ;;
    esac
done

set -e
adb $ADBOPTS push "$CLICK" /tmp
click_name=`basename $CLICK`
adb $ADBOPTS shell sudo -u $DEVICE_USER bash -ic "pkcon install-local /tmp/$click_name"

# The PY2_SUBDIR logic is from lp:phablet-tools phablet-click-test-setup
# It is replicated here because we are using a merged branch, not something
# that is present in launchpad.
PY2_SUBDIR='legacy-py2'
TARGET_DIR=/home/$DEVICE_USER/autopilot/$PY2_SUBDIR

#phablet-click-test-setup --click $CLICK
click_info=`adb $ADBOPTS shell click info /tmp/$click_name`
if echo $click_info | grep -q 'x-test'; then
    if echo $click_info | grep -q 'autopilot'; then
       echo "Looks like python3-autopilot tests"
       TARGET_DIR=/home/$DEVICE_USER/autopilot
    fi
fi
adb $ADBOPTS shell mkdir -p $TARGET_DIR
adb $ADBOPTS push $SOURCE_DIR/tests/autopilot $TARGET_DIR
adb $ADBOPTS shell chown -R "$DEVICE_USER":"$DEVICE_USER" /home/$DEVICE_USER/autopilot
set +e

echo Allowing autopilot to play well with apparmor
phablet-config autopilot --dbus-probe enable
echo "Ready to run autopilot"
