#!/usr/bin/env python

from mock import (MagicMock, patch)
import os
from testtools import TestCase
from testscenarios import TestWithScenarios

from um_provision import convert_hook_to_ppa, provision

class UpstreamMergerProvision(TestCase):
    def setUp(self):
        super(UpstreamMergerProvision, self).setUp()

class ConvertHookToPpa(TestWithScenarios, UpstreamMergerProvision):
    scenarios = [
        ('single_ppa_hook',
         {
             'hooks': 'D09add_ppa~team-name~ppa-name',
             'ppa': ['ppa:team-name/ppa-name']}
        ),
        ('single_hook_not_a_ppa',
         {
             'hooks': 'D10not_a_ppa_hook',
             'ppa': []}
        ),
        ('multiple_ppa_hooks',
         {
             'hooks': 'D09add_ppa~team-name~ppa-name D09add_ppa~team2~ppa2 '
             'D10not_a_ppa_hook',
             'ppa': ['ppa:team-name/ppa-name', 'ppa:team2/ppa2']}
        ),
        ('no_hooks',
         {
             'hooks': '',
             'ppa': []}
        )
    ]

    def setUp(self):
        super(ConvertHookToPpa, self).setUp()

    def test_convert_hook_to_ppa(self):
        self.assertEqual(self.ppa, convert_hook_to_ppa(self.hooks))


class Provision(TestWithScenarios, UpstreamMergerProvision):
    scenarios = [
        ('specify_serial',
         {'args': {'serial': 'abcdef1234567890'},
          'cmd': ['provision.sh', '-s', 'abcdef1234567890']}
        ),
        ('specify_single_archive_directory',
         {'args': {'archive_directories': ['archive-1']},
          'cmd': ['provision.sh', '-D', 'archive-1']}
        ),
        ('specify_multiple_archive_directories',
         {'args': {'archive_directories': ['archive-1', 'archive-2']},
          'cmd': ['provision.sh', '-D', 'archive-1', '-D', 'archive-2']}
        ),
        ('specify_single_ppa',
         {'args': {'ppa_list': ['ppa:team-1/name-1']},
          'cmd': ['provision.sh', '-P', 'ppa:team-1/name-1']}
        ),
        ('specify_multiple_ppas',
         {'args': {'ppa_list': ['ppa:team-1/name-1', 'ppa:team-2/name-2']},
          'cmd': ['provision.sh', '-P', 'ppa:team-1/name-1',
                  '-P', 'ppa:team-2/name-2']}
        ),
        ('specify_single_deb_package',
         {'args': {'deb_packages': ['package-1']},
          'cmd': ['provision.sh', '-p', 'package-1']}
        ),
        ('specify_multiple_deb_package',
         {'args': {'deb_packages': ['package-1', 'package-2']},
          'cmd': ['provision.sh', '-p', 'package-1', '-p', 'package-2']}
        ),
        ('specify_ppa_and_package',
         {'args': {'ppa_list': ['ppa:team-1/name-1'],
                   'deb_packages': ['package-1']},
          'cmd': ['provision.sh', '-P', 'ppa:team-1/name-1',
                  '-p', 'package-1']}
        ),
        ('specify_archive_dir_and_package',
         {'args': {'archive_directories': ['archive-1'],
                   'deb_packages': ['package-1']},
          'cmd': ['provision.sh', '-D', 'archive-1', '-p', 'package-1']}
        ),
        ('specify_archive_dir_ppa_and_package',
         {'args': {'archive_directories': ['archive_dir'],
                   'ppa_list': ['ppa:team-1/name-1'],
                   'deb_packages': ['package-1']},
          'cmd': ['provision.sh', '-D', 'archive_dir',
                  '-P', 'ppa:team-1/name-1', '-p', 'package-1']}
        ),
    ]

    @patch('subprocess.check_call')
    def test_provision(self, call_mock):
        provision(**self.args)
        call_mock.assert_called_with(self.cmd)

